# malama

A simple multi-utility Python package with:

- Text Cleaner
- Currency Formatter
- Human Time Converter
- Password Strength Checker
- File Size Formatter

## Installation

```bash
pip install malama
